NXSConfigServer Tango Class Command InstantiatedComponents

Command InstantiatedComponents :

Returns a list of required components

InstantiatedComponents Definition
Input Argument | Tango::DEVVAR_STRINGARRAY | list of component names
Output Argument | Tango::DEVVAR_STRINGARRAY | list of instantiated components
DisplayLevel | OPERATOR | ..
Inherited | false | ..
Abstract | false | ..
Polling Period | Not polled | ..
Command NOT allowed for | ON RUNNING | ..